/*
 * library ic1306.c
 * v1.3
 * Created on: 27 may 2020.
 * Author: Maxim Ilyn imax9@narod.ru
 */

#include "main.h"
#include <ic1306.h>
extern I2C_HandleTypeDef hi2c1;

ssd1306_I2C_Write(uint8_t address, uint8_t reg, uint8_t data) {
	uint8_t dt[2];
	dt[0] = reg;
	dt[1] = data;
	HAL_I2C_Master_Transmit(&hi2c1, address, dt, 2,50);
}

/* Write command */
#define SSD1306_WRITECOMMAND(command)      ssd1306_I2C_Write(SSD1306_I2C_ADDR, 0x00, (command))
/* Write data */
#define SSD1306_WRITEDATA(data)            ssd1306_I2C_Write(SSD1306_I2C_ADDR, 0x40, (data))

void display_init (uint8_t contrast, uint8_t bright, uint8_t mirror)
{
		SSD1306_WRITECOMMAND(0xAE); //display off
//		SSD1306_WRITECOMMAND(0xC8); //Set COM Output Scan Direction
		SSD1306_WRITECOMMAND(0x00); //---set low column address
		SSD1306_WRITECOMMAND(0x10); //---set high column address
		SSD1306_WRITECOMMAND(0x40); //--set start line address
		SSD1306_WRITECOMMAND(0x81); //--set contrast control register
		SSD1306_WRITECOMMAND(contrast);
		if (mirror)
		{SSD1306_WRITECOMMAND(0xC0); //Set COM Output Scan Direction
		SSD1306_WRITECOMMAND(0xA0);} //--set segment re-map 0 to 127
		else {SSD1306_WRITECOMMAND(0xC8); //Set COM Output Scan Direction
		SSD1306_WRITECOMMAND(0xA1);} //--set segment re-map 0 to 127
		SSD1306_WRITECOMMAND(0xA6); //--set normal display
		SSD1306_WRITECOMMAND(0xA8); //--set multiplex ratio(1 to 64)
		SSD1306_WRITECOMMAND(0x3F); //
		SSD1306_WRITECOMMAND(0xA4); //0xa4,Output follows RAM content;0xa5,Output ignores RAM content
		SSD1306_WRITECOMMAND(0xD3); //-set display offset
		SSD1306_WRITECOMMAND(0x00); //-not offset
		SSD1306_WRITECOMMAND(0xD5); //--set display clock divide ratio/oscillator frequency
		SSD1306_WRITECOMMAND(0xF0); //--set divide ratio
		SSD1306_WRITECOMMAND(0xD9); //--set pre-charge period
		SSD1306_WRITECOMMAND(bright); //
		SSD1306_WRITECOMMAND(0xDA); //--set com pins hardware configuration
		SSD1306_WRITECOMMAND(0x12);
		SSD1306_WRITECOMMAND(0xDB); //--set vcomh
		SSD1306_WRITECOMMAND(0x20); //0x20,0.77xVcc
		SSD1306_WRITECOMMAND(0x8D); //--set DC-DC enable
		SSD1306_WRITECOMMAND(0x14); //
		SSD1306_WRITECOMMAND(0xAF); //--turn on SSD1306 panel
}


void display_clear(uint8_t start, uint8_t stop)
{ uint32_t *adrclear;
uint32_t timer,timec;
  uint8_t dt[128+1];
  adrclear=&dt;
   for(uint8_t i=0;i<32;i++)
   {*adrclear++=0;}
	dt[128]=0;
	dt[0]=0x40;
	for (uint8_t m = start; m <= stop; m++) {
	SSD1306_WRITECOMMAND(0x20);
	SSD1306_WRITECOMMAND(0x01);
	SSD1306_WRITECOMMAND(0x21);
  	SSD1306_WRITECOMMAND(0);
  	SSD1306_WRITECOMMAND(127);
  	SSD1306_WRITECOMMAND(0x22);
  	SSD1306_WRITECOMMAND(m);
  	SSD1306_WRITECOMMAND(m);
	HAL_I2C_Master_Transmit_DMA(&hi2c1, SSD1306_I2C_ADDR, dt, 128+1);
	timec=HAL_GetTick();
	timer=timec+50;
	while ((HAL_I2C_GetState(&hi2c1) != HAL_I2C_STATE_READY)&&(timec<timer))
	{timec=HAL_GetTick();}
 }
}

const uint8_t MediumFont[] =																							//		MediumFont
{																															//
0x0C,0x10,0x20,0x5F,																										//	  (12),   (16),    (32),   (95)
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	//	001)	0x20=032	
0x00,0x00,0x00,0x00,0x00,0xFE,0xFE,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x67,0x67,0x00,0x00,0x00,0x00,0x00,	//	002)	0x21=033	!
0x00,0x00,0x00,0x16,0x0E,0x00,0x00,0x16,0x0E,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	//	003)	0x22=034	"
0x00,0x00,0x60,0xE0,0xF8,0x7E,0x6E,0xE0,0xF8,0x7E,0x6E,0x00,0x00,0x76,0x7E,0x1F,0x07,0x76,0x7E,0x1F,0x07,0x06,0x00,0x00,	//	004)	0x23=035	#
0x00,0x78,0xFC,0xCE,0x86,0xFF,0xFF,0x86,0x9E,0x1C,0x18,0x00,0x00,0x18,0x38,0x79,0x61,0xFF,0xFF,0x61,0x73,0x3F,0x1E,0x00,	//	005)	0x24=036	$
0x00,0x3C,0x7E,0x66,0x7E,0xBC,0xE0,0x78,0x1E,0x06,0x00,0x00,0x00,0x00,0x60,0x78,0x1E,0x07,0x3D,0x7E,0x66,0x7E,0x3C,0x00,	//	006)	0x25=037	%
0x00,0x00,0x00,0x80,0x80,0xFC,0xFE,0xE6,0xE6,0x7E,0x3C,0x00,0x00,0x1E,0x3F,0x73,0x61,0x61,0x71,0x7F,0x3F,0x7C,0x6C,0x00,	//	007)	0x26=038	&
0x00,0x00,0x00,0x00,0x00,0x16,0x0E,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	//	008)	0x27=039	'
0x00,0x00,0x00,0x00,0xF0,0xFC,0x0E,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0x3F,0x70,0xC0,0x00,0x00,0x00,0x00,	//	009)	0x28=040	(
0x00,0x00,0x00,0x00,0x03,0x0E,0xFC,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC0,0x70,0x3F,0x0F,0x00,0x00,0x00,0x00,	//	010)	0x29=041	)
0x00,0x00,0x00,0x08,0x78,0x3C,0x3C,0x78,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	//	011)	0x2A=042	*
0x00,0x00,0x80,0x80,0x80,0xF0,0xF0,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x0F,0x0F,0x01,0x01,0x01,0x00,0x00,	//	012)	0x2B=043	+
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xB0,0x70,0x00,0x00,0x00,0x00,0x00,	//	013)	0x2C=044	,
0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,	//	014)	0x2D=045	-
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x60,0x00,0x00,0x00,0x00,0x00,	//	015)	0x2E=046	.
0x00,0x00,0x00,0x00,0x00,0x80,0xE0,0x78,0x1E,0x06,0x00,0x00,0x00,0x00,0x60,0x78,0x1E,0x07,0x01,0x00,0x00,0x00,0x00,0x00,	//	016)	0x2F=047	/
																															//
0x00,0xF8,0xFC,0x0E,0x06,0x06,0x06,0x06,0x0E,0xFC,0xF8,0x00,0x00,0x1F,0x3F,0x70,0x60,0x60,0x60,0x60,0x70,0x3F,0x1F,0x00,	//	017)	0x30=048	0
0x00,0x00,0x00,0x30,0x38,0x1C,0xFE,0xFE,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x7F,0x7F,0x60,0x00,0x00,0x00,	//	018)	0x31=049	1
0x00,0x18,0x1C,0x1E,0x06,0x06,0x06,0x86,0xCE,0xFC,0x78,0x00,0x00,0x78,0x7C,0x7E,0x66,0x67,0x63,0x63,0x61,0x70,0x70,0x00,	//	019)	0x32=050	2
0x00,0x0E,0x0E,0x06,0x06,0xC6,0xE6,0xF6,0xFE,0x9E,0x0E,0x00,0x00,0x18,0x38,0x78,0x60,0x60,0x60,0x60,0x71,0x3F,0x1F,0x00,	//	020)	0x33=051	3
0x00,0x00,0x80,0xC0,0xE0,0x70,0x38,0x1C,0xFE,0xFE,0x06,0x00,0x00,0x07,0x07,0x07,0x06,0x06,0x06,0x66,0x7F,0x7F,0x66,0x00,	//	021)	0x34=052	4
0x00,0xFE,0xFE,0xE6,0x66,0x66,0x66,0x66,0xE6,0xCE,0x8E,0x00,0x00,0x18,0x38,0x78,0x60,0x60,0x60,0x60,0x70,0x3F,0x1F,0x00,	//	022)	0x35=053	5
0x00,0xF8,0xFC,0xCE,0xC6,0xC6,0xC6,0xC6,0xDE,0x9C,0x18,0x00,0x00,0x1F,0x3F,0x71,0x60,0x60,0x60,0x60,0x71,0x3F,0x1F,0x00,	//	023)	0x36=054	6
0x00,0x1E,0x1E,0x06,0x06,0x06,0x06,0x86,0xE6,0x7E,0x1E,0x00,0x00,0x00,0x00,0x00,0x60,0x78,0x1E,0x07,0x01,0x00,0x00,0x00,	//	024)	0x37=055	7
0x00,0x78,0xFC,0xCE,0x86,0x86,0x86,0x86,0xCE,0xFC,0x78,0x00,0x00,0x1E,0x3F,0x73,0x61,0x61,0x61,0x61,0x73,0x3F,0x1E,0x00,	//	025)	0x38=056	8
0x00,0xF8,0xFC,0x8E,0x06,0x06,0x06,0x06,0x8E,0xFC,0xF8,0x00,0x00,0x18,0x39,0x7B,0x63,0x63,0x63,0x63,0x73,0x3F,0x1F,0x00,	//	026)	0x39=057	9
0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0C,0x0C,0x00,0x00,0x00,0x00,0x00,	//	027)	0x3A=058	:
0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2C,0x1C,0x00,0x00,0x00,0x00,0x00,	//	028)	0x3B=059	;
0x00,0x00,0x80,0xC0,0xC0,0xE0,0x60,0x70,0x30,0x30,0x00,0x00,0x00,0x00,0x01,0x03,0x03,0x07,0x06,0x0E,0x0C,0x0C,0x00,0x00,	//	029)	0x3C=060	<
0x00,0x00,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,0x00,0x00,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x00,0x00,	//	030)	0x3D=061	=
0x00,0x00,0x30,0x30,0x70,0x60,0xE0,0xC0,0xC0,0x80,0x00,0x00,0x00,0x00,0x0C,0x0C,0x0E,0x06,0x07,0x03,0x03,0x01,0x00,0x00,	//	031)	0x3E=062	>
0x00,0x18,0x1C,0x1E,0x06,0x06,0x86,0x86,0xCE,0xFC,0x78,0x00,0x00,0x00,0x00,0x00,0x6E,0x6F,0x03,0x01,0x01,0x00,0x00,0x00,	//	032)	0x3F=063	?
																															//
0x00,0xF8,0xFC,0x0E,0xE6,0xF6,0x36,0xF6,0xF6,0x0E,0xFC,0xF8,0x00,0x1F,0x3F,0x70,0x67,0x6F,0x6C,0x6F,0x67,0x6C,0x2F,0x07,	//	033)	0x40=064	@
0x00,0x00,0xF0,0xFC,0x1E,0x06,0x06,0x06,0xFE,0xFE,0x06,0x00,0x00,0x60,0x7F,0x7F,0x63,0x03,0x03,0x63,0x7F,0x7F,0x60,0x00,	//	034)	0x41=065	A
0x00,0x06,0xFE,0xFE,0x86,0x86,0x86,0x86,0xCE,0xFC,0x78,0x00,0x00,0x60,0x7F,0x7F,0x61,0x61,0x61,0x61,0x73,0x3F,0x1E,0x00,	//	035)	0x42=066	B
0x00,0xF8,0xFC,0x0E,0x06,0x06,0x06,0x06,0x1E,0x1C,0x18,0x00,0x00,0x1F,0x3F,0x70,0x60,0x60,0x60,0x60,0x78,0x38,0x18,0x00,	//	036)	0x43=067	C
0x00,0x06,0xFE,0xFE,0x06,0x06,0x06,0x06,0x0E,0xFC,0xF8,0x00,0x00,0x60,0x7F,0x7F,0x60,0x60,0x60,0x60,0x70,0x3F,0x1F,0x00,	//	037)	0x44=068	D
0x00,0x06,0xFE,0xFE,0x86,0x86,0x86,0xC6,0xC6,0x0E,0x0E,0x00,0x00,0x60,0x7F,0x7F,0x61,0x61,0x61,0x63,0x63,0x70,0x70,0x00,	//	038)	0x45=069	E
0x00,0x06,0xFE,0xFE,0x86,0x86,0xC6,0xC6,0x06,0x0E,0x0E,0x00,0x00,0x60,0x7F,0x7F,0x61,0x01,0x03,0x03,0x00,0x00,0x00,0x00,	//	039)	0x46=070	F
0x00,0xF8,0xFC,0x0E,0x06,0x06,0x06,0x06,0x1E,0x1C,0x18,0x00,0x00,0x1F,0x3F,0x70,0x60,0x60,0x63,0x63,0x73,0x3F,0x1F,0x00,	//	040)	0x47=071	G
0x00,0x06,0xFE,0xFE,0x86,0x80,0x80,0x86,0xFE,0xFE,0x06,0x00,0x00,0x60,0x7F,0x7F,0x61,0x01,0x01,0x61,0x7F,0x7F,0x60,0x00,	//	041)	0x48=072	H
0x00,0x00,0x00,0x00,0x06,0xFE,0xFE,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x7F,0x7F,0x60,0x00,0x00,0x00,0x00,	//	042)	0x49=073	I
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0xFE,0xFE,0x06,0x00,0x00,0x00,0x18,0x38,0x78,0x60,0x60,0x70,0x3F,0x1F,0x00,0x00,	//	043)	0x4A=074	J
0x00,0x06,0xFE,0xFE,0x86,0x80,0xC0,0xF6,0x7E,0x1E,0x06,0x00,0x00,0x60,0x7F,0x7F,0x61,0x01,0x03,0x6F,0x7E,0x78,0x60,0x00,	//	044)	0x4B=075	K
0x00,0x06,0xFE,0xFE,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x7F,0x7F,0x60,0x60,0x60,0x60,0x60,0x70,0x70,0x00,	//	045)	0x4C=076	L
0x00,0x06,0xFE,0xFE,0x78,0xE0,0xE0,0x78,0xFE,0xFE,0x06,0x00,0x00,0x60,0x7F,0x7F,0x60,0x01,0x01,0x60,0x7F,0x7F,0x60,0x00,	//	046)	0x4D=077	M
0x00,0x06,0xFE,0xFE,0x78,0xE0,0x80,0x06,0xFE,0xFE,0x06,0x00,0x00,0x60,0x7F,0x7F,0x60,0x01,0x07,0x1E,0x7F,0x7F,0x60,0x00,	//	047)	0x4E=078	N
0x00,0xF8,0xFC,0x0E,0x06,0x06,0x06,0x06,0x0E,0xFC,0xF8,0x00,0x00,0x1F,0x3F,0x70,0x60,0x60,0x60,0x60,0x70,0x3F,0x1F,0x00,	//	048)	0x4F=079	O
																															//
0x00,0x06,0xFE,0xFE,0x06,0x06,0x06,0x06,0x8E,0xFC,0xF8,0x00,0x00,0x60,0x7F,0x7F,0x63,0x03,0x03,0x03,0x03,0x01,0x00,0x00,	//	049)	0x50=080	P
0x00,0xF8,0xFC,0x0E,0x06,0x06,0x06,0x06,0x0E,0xFC,0xF8,0x00,0x00,0x1F,0x3F,0x70,0x60,0x60,0x6C,0x7C,0x38,0x7F,0x6F,0x00,	//	050)	0x51=081	Q
0x00,0x06,0xFE,0xFE,0x06,0x06,0x06,0x06,0x8E,0xFC,0xF8,0x00,0x00,0x60,0x7F,0x7F,0x63,0x03,0x03,0x6F,0x7F,0x79,0x60,0x00,	//	051)	0x52=082	R
0x00,0x78,0xFC,0xCE,0x86,0x86,0x86,0x86,0x9E,0x1C,0x18,0x00,0x00,0x18,0x38,0x79,0x61,0x61,0x61,0x61,0x73,0x3F,0x1E,0x00,	//	052)	0x53=083	S
0x00,0x0E,0x0E,0x06,0x06,0xFE,0xFE,0x06,0x06,0x0E,0x0E,0x00,0x00,0x00,0x00,0x00,0x60,0x7F,0x7F,0x60,0x00,0x00,0x00,0x00,	//	053)	0x54=084	T
0x00,0x06,0xFE,0xFE,0x06,0x00,0x00,0x06,0xFE,0xFE,0x06,0x00,0x00,0x00,0x1F,0x3F,0x70,0x60,0x60,0x70,0x3F,0x1F,0x00,0x00,	//	054)	0x55=085	U
0x00,0x06,0xFE,0xFE,0x06,0x00,0x00,0x06,0xFE,0xFE,0x06,0x00,0x00,0x00,0x03,0x0F,0x3E,0x78,0x78,0x3E,0x0F,0x03,0x00,0x00,	//	055)	0x56=086	V
0x00,0x06,0xFE,0xFE,0x06,0x80,0x80,0x06,0xFE,0xFE,0x06,0x00,0x00,0x00,0x1F,0x7F,0x78,0x1F,0x1F,0x78,0x7F,0x1F,0x00,0x00,	//	056)	0x57=087	W
0x00,0x06,0x1E,0x7E,0xF6,0xC0,0xC0,0xF6,0x7E,0x1E,0x06,0x00,0x00,0x60,0x78,0x7E,0x6F,0x03,0x03,0x6F,0x7E,0x78,0x60,0x00,	//	057)	0x58=088	X
0x00,0x06,0x7E,0xFE,0xC6,0x00,0x00,0xC6,0xFE,0x7E,0x06,0x00,0x00,0x00,0x00,0x01,0x63,0x7F,0x7F,0x63,0x01,0x00,0x00,0x00,	//	058)	0x59=089	Y
0x00,0x0E,0x0E,0x06,0x06,0x86,0xC6,0xE6,0x76,0x3E,0x1E,0x00,0x00,0x78,0x7C,0x6E,0x67,0x63,0x61,0x60,0x60,0x70,0x70,0x00,	//	059)	0x5A=090	Z
0x00,0x00,0x00,0x00,0xFF,0xFF,0x03,0x03,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xC0,0xC0,0xC0,0x00,0x00,0x00,	//	060)	0x5B=091	[
0x00,0x00,0x06,0x1E,0x78,0xE0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x07,0x1E,0x78,0x60,0x00,0x00,	//	061)	0x5C=092	 
0x00,0x00,0x00,0x03,0x03,0x03,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC0,0xC0,0xC0,0xFF,0xFF,0x00,0x00,0x00,0x00,	//	062)	0x5D=093	]
0x00,0x00,0x00,0x30,0x3C,0x1E,0x1E,0x3C,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	//	063)	0x5E=094	^
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x00,	//	064)	0x5F=095	_
																															//
0x00,0x00,0x00,0x00,0x00,0x0E,0x0E,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	//	065)	0x60=096	`
0x00,0xC0,0xE0,0x70,0x30,0x30,0x30,0x70,0xE0,0xC0,0x00,0x00,0x00,0x1C,0x3E,0x77,0x63,0x63,0x63,0x33,0x7F,0x7F,0x60,0x00,	//	066)	0x61=097	a
0x00,0x06,0xFE,0xFE,0x66,0x30,0x30,0x30,0x70,0xE0,0xC0,0x00,0x00,0x60,0x7F,0x7F,0x30,0x60,0x60,0x60,0x70,0x3F,0x1F,0x00,	//	067)	0x62=098	b
0x00,0xC0,0xE0,0x70,0x30,0x30,0x30,0x30,0xF0,0xE0,0xC0,0x00,0x00,0x1F,0x3F,0x70,0x60,0x60,0x60,0x60,0x78,0x38,0x18,0x00,	//	068)	0x63=099	c
0x00,0xC0,0xE0,0x70,0x30,0x30,0x30,0x66,0xFE,0xFE,0x06,0x00,0x00,0x1F,0x3F,0x70,0x60,0x60,0x60,0x30,0x7F,0x7F,0x60,0x00,	//	069)	0x64=100	d
0x00,0xC0,0xE0,0x70,0x30,0x30,0x30,0x30,0x70,0xE0,0xC0,0x00,0x00,0x1F,0x3F,0x76,0x66,0x66,0x66,0x66,0x76,0x37,0x17,0x00,	//	070)	0x65=101	e
0x00,0x00,0x00,0x60,0xFC,0xFE,0x66,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7F,0x7F,0x00,0x00,0x00,0x00,0x00,0x00,	//	071)	0x66=102	f
0x00,0xC0,0xE0,0x70,0x30,0x30,0x30,0x60,0xF0,0xF0,0x30,0x00,0x00,0x33,0x77,0xEE,0xCC,0xCC,0xCC,0xEE,0x7F,0x3F,0x00,0x00,	//	072)	0x67=103	g
0x00,0x06,0xFE,0xFE,0x66,0x30,0x30,0x70,0xE0,0xC0,0x00,0x00,0x00,0x60,0x7F,0x7F,0x60,0x00,0x00,0x60,0x7F,0x7F,0x60,0x00,	//	073)	0x68=104	h
0x00,0x00,0x00,0x00,0x30,0xF6,0xF6,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x7F,0x7F,0x60,0x00,0x00,0x00,0x00,	//	074)	0x69=105	i
0x00,0x00,0x00,0x00,0x00,0x30,0xF6,0xF6,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x60,0x7F,0x3F,0x00,0x00,0x00,0x00,	//	075)	0x6A=106	j
0x00,0x06,0xFE,0xFE,0x06,0x80,0xF0,0xF0,0x70,0x30,0x30,0x00,0x00,0x60,0x7F,0x7F,0x63,0x07,0x0F,0x7C,0x78,0x70,0x60,0x00,	//	076)	0x6B=107	k
0x00,0x00,0x00,0x00,0x06,0xFE,0xFE,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x7F,0x7F,0x60,0x00,0x00,0x00,0x00,	//	077)	0x6C=108	l
0x30,0xF0,0xE0,0x30,0x30,0xF0,0xE0,0x30,0x30,0xF0,0xE0,0x00,0x60,0x7F,0x7F,0x60,0x00,0x7F,0x7F,0x00,0x60,0x7F,0x7F,0x60,	//	078)	0x6D=109	m
0x00,0x30,0xF0,0xF0,0x60,0x30,0x30,0x70,0xE0,0xC0,0x00,0x00,0x00,0x60,0x7F,0x7F,0x60,0x00,0x00,0x60,0x7F,0x7F,0x60,0x00,	//	079)	0x6E=110	n
0x00,0xC0,0xE0,0x70,0x30,0x30,0x30,0x30,0x70,0xE0,0xC0,0x00,0x00,0x1F,0x3F,0x70,0x60,0x60,0x60,0x60,0x70,0x3F,0x1F,0x00,	//	080)	0x6F=111	o
																															//
0x00,0x30,0xF0,0xF0,0x60,0x30,0x30,0x30,0x70,0xE0,0xC0,0x00,0x00,0xC0,0xFF,0xFF,0xD8,0x30,0x30,0x30,0x38,0x1F,0x0F,0x00,	//	081)	0x70=112	p
0x00,0xC0,0xE0,0x70,0x30,0x30,0x30,0x60,0xF0,0xF0,0x30,0x00,0x00,0x0F,0x1F,0x38,0x30,0x30,0x30,0xD8,0xFF,0xFF,0xC0,0x00,	//	082)	0x71=113	q
0x00,0x00,0x30,0xF0,0xF0,0x60,0x30,0x30,0x70,0x60,0x00,0x00,0x00,0x00,0x60,0x7F,0x7F,0x60,0x00,0x00,0x00,0x00,0x00,0x00,	//	083)	0x72=114	r
0x00,0xE0,0xF0,0x30,0x30,0x30,0x30,0x30,0x70,0x70,0x60,0x00,0x00,0x19,0x3B,0x7B,0x63,0x63,0x63,0x63,0x77,0x3E,0x1C,0x00,	//	084)	0x73=115	s
0x00,0x00,0x00,0x30,0xFE,0xFE,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x7F,0x60,0x60,0x00,0x00,0x00,0x00,	//	085)	0x74=116	t
0x00,0x30,0xF0,0xF0,0x30,0x00,0x00,0x30,0xF0,0xF0,0x30,0x00,0x00,0x00,0x1F,0x3F,0x70,0x60,0x60,0x30,0x7F,0x7F,0x60,0x00,	//	086)	0x75=117	u
0x00,0x30,0xF0,0xF0,0x30,0x00,0x00,0x30,0xF0,0xF0,0x30,0x00,0x00,0x00,0x00,0x07,0x1F,0x78,0x78,0x1F,0x07,0x00,0x00,0x00,	//	087)	0x76=118	v
0x30,0xF0,0xF0,0x30,0x00,0x00,0x00,0x00,0x30,0xF0,0xF0,0x30,0x00,0x03,0x1F,0x7C,0x70,0x1E,0x1E,0x70,0x7C,0x1F,0x03,0x00,	//	088)	0x77=119	w
0x00,0x00,0x30,0x70,0xF0,0x80,0x80,0xF0,0x70,0x30,0x00,0x00,0x00,0x00,0x60,0x70,0x7D,0x0F,0x0F,0x7D,0x70,0x60,0x00,0x00,	//	089)	0x78=120	x
0x00,0x00,0x30,0xF0,0xC0,0x00,0x00,0xC0,0xF0,0x30,0x00,0x00,0x00,0x00,0x60,0x60,0x73,0x3F,0x0F,0x03,0x00,0x00,0x00,0x00,	//	090)	0x79=121	y
0x00,0x00,0x70,0x70,0x30,0x30,0xB0,0xF0,0xF0,0x70,0x00,0x00,0x00,0x00,0x78,0x7C,0x6E,0x67,0x63,0x61,0x70,0x70,0x00,0x00,	//	091)	0x7A=122	z
0x00,0x00,0x80,0xC0,0xFC,0x7E,0x07,0x03,0x03,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x3F,0x7E,0xE0,0xC0,0xC0,0x00,0x00,0x00,	//	092)	0x7B=123	{
0x00,0x00,0x00,0x00,0x00,0xFE,0xFE,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7F,0x7F,0x00,0x00,0x00,0x00,0x00,	//	093)	0x7C=124	|
0x00,0x00,0x00,0x03,0x03,0x07,0x7E,0xFC,0xC0,0x80,0x00,0x00,0x00,0x00,0x00,0xC0,0xC0,0xE0,0x7E,0x3F,0x03,0x01,0x00,0x00,	//	094)	0x7D=125	}
0x00,0x80,0xC0,0xC0,0xC0,0xC0,0x80,0x00,0x00,0x80,0x80,0x00,0x00,0x01,0x01,0x00,0x00,0x01,0x03,0x03,0x03,0x03,0x01,0x00,	//	095)	0x7E=126	~
																															//
0																															//	   (0)  . .    .
};
const uint8_t SmallFont[] =				//		SmallFont
{												//
0x06, 0x08, 0x20, 0x5F,							//	  (6),   (8),    (32),   (95)
												//
0x00, 0x00, 0x00, 0x00, 0x00, 0x00,				//	001)	0x20=032	
0x00, 0x00, 0x00, 0x2F, 0x00, 0x00,				//	002)	0x21=033	!
0x00, 0x00, 0x07, 0x00, 0x07, 0x00,				//	003)	0x22=034	"
0x00, 0x14, 0x7F, 0x14, 0x7F, 0x14,				//	004)	0x23=035	#
0x00, 0x24, 0x2A, 0x7F, 0x2A, 0x12,				//	005)	0x24=036	$
0x00, 0x23, 0x13, 0x08, 0x64, 0x62,				//	006)	0x25=037	%
0x00, 0x36, 0x49, 0x55, 0x22, 0x50,				//	007)	0x26=038	&
0x00, 0x00, 0x05, 0x03, 0x00, 0x00,				//	008)	0x27=039	'
0x00, 0x00, 0x1C, 0x22, 0x41, 0x00,				//	009)	0x28=040	(
0x00, 0x00, 0x41, 0x22, 0x1C, 0x00,				//	010)	0x29=041	)
0x00, 0x14, 0x08, 0x3E, 0x08, 0x14,				//	011)	0x2A=042	*
0x00, 0x08, 0x08, 0x3E, 0x08, 0x08,				//	012)	0x2B=043	+
0x00, 0x00, 0x00, 0xA0, 0x60, 0x00,				//	013)	0x2C=044	,
0x00, 0x08, 0x08, 0x08, 0x08, 0x08,				//	014)	0x2D=045	-
0x00, 0x00, 0x60, 0x60, 0x00, 0x00,				//	015)	0x2E=046	.
0x00, 0x20, 0x10, 0x08, 0x04, 0x02,				//	016)	0x2F=047	/
												//
0x00, 0x3E, 0x51, 0x49, 0x45, 0x3E,				//	017)	0x30=048	0
0x00, 0x00, 0x42, 0x7F, 0x40, 0x00,				//	018)	0x31=049	1
0x00, 0x42, 0x61, 0x51, 0x49, 0x46,				//	019)	0x32=050	2
0x00, 0x21, 0x41, 0x45, 0x4B, 0x31,				//	020)	0x33=051	3
0x00, 0x18, 0x14, 0x12, 0x7F, 0x10,				//	021)	0x34=052	4
0x00, 0x27, 0x45, 0x45, 0x45, 0x39,				//	022)	0x35=053	5
0x00, 0x3C, 0x4A, 0x49, 0x49, 0x30,				//	023)	0x36=054	6
0x00, 0x01, 0x71, 0x09, 0x05, 0x03,				//	024)	0x37=055	7
0x00, 0x36, 0x49, 0x49, 0x49, 0x36,				//	025)	0x38=056	8
0x00, 0x06, 0x49, 0x49, 0x29, 0x1E,				//	026)	0x39=057	9
0x00, 0x00, 0x36, 0x36, 0x00, 0x00,				//	027)	0x3A=058	:
0x00, 0x00, 0x56, 0x36, 0x00, 0x00,				//	028)	0x3B=059	;
0x00, 0x08, 0x14, 0x22, 0x41, 0x00,				//	029)	0x3C=060	<
0x00, 0x14, 0x14, 0x14, 0x14, 0x14,				//	030)	0x3D=061	=
0x00, 0x00, 0x41, 0x22, 0x14, 0x08,				//	031)	0x3E=062	>
0x00, 0x02, 0x01, 0x51, 0x09, 0x06,				//	032)	0x3F=063	?
												//
0x00, 0x32, 0x49, 0x59, 0x51, 0x3E,				//	033)	0x40=064	@
0x00, 0x7C, 0x12, 0x11, 0x12, 0x7C,				//	034)	0x41=065	A
0x00, 0x7F, 0x49, 0x49, 0x49, 0x36,				//	035)	0x42=066	B
0x00, 0x3E, 0x41, 0x41, 0x41, 0x22,				//	036)	0x43=067	C
0x00, 0x7F, 0x41, 0x41, 0x22, 0x1C,				//	037)	0x44=068	D
0x00, 0x7F, 0x49, 0x49, 0x49, 0x41,				//	038)	0x45=069	E
0x00, 0x7F, 0x09, 0x09, 0x09, 0x01,				//	039)	0x46=070	F
0x00, 0x3E, 0x41, 0x49, 0x49, 0x7A,				//	040)	0x47=071	G
0x00, 0x7F, 0x08, 0x08, 0x08, 0x7F,				//	041)	0x48=072	H
0x00, 0x00, 0x41, 0x7F, 0x41, 0x00,				//	042)	0x49=073	I
0x00, 0x20, 0x40, 0x41, 0x3F, 0x01,				//	043)	0x4A=074	J
0x00, 0x7F, 0x08, 0x14, 0x22, 0x41,				//	044)	0x4B=075	K
0x00, 0x7F, 0x40, 0x40, 0x40, 0x40,				//	045)	0x4C=076	L
0x00, 0x7F, 0x02, 0x0C, 0x02, 0x7F,				//	046)	0x4D=077	M
0x00, 0x7F, 0x04, 0x08, 0x10, 0x7F,				//	047)	0x4E=078	N
0x00, 0x3E, 0x41, 0x41, 0x41, 0x3E,				//	048)	0x4F=079	O
												//
0x00, 0x7F, 0x09, 0x09, 0x09, 0x06,				//	049)	0x50=080	P
0x00, 0x3E, 0x41, 0x51, 0x21, 0x5E,				//	050)	0x51=081	Q
0x00, 0x7F, 0x09, 0x19, 0x29, 0x46,				//	051)	0x52=082	R
0x00, 0x46, 0x49, 0x49, 0x49, 0x31,				//	052)	0x53=083	S
0x00, 0x01, 0x01, 0x7F, 0x01, 0x01,				//	053)	0x54=084	T
0x00, 0x3F, 0x40, 0x40, 0x40, 0x3F,				//	054)	0x55=085	U
0x00, 0x1F, 0x20, 0x40, 0x20, 0x1F,				//	055)	0x56=086	V
0x00, 0x3F, 0x40, 0x38, 0x40, 0x3F,				//	056)	0x57=087	W
0x00, 0x63, 0x14, 0x08, 0x14, 0x63,				//	057)	0x58=088	X
0x00, 0x07, 0x08, 0x70, 0x08, 0x07,				//	058)	0x59=089	Y
0x00, 0x61, 0x51, 0x49, 0x45, 0x43,				//	059)	0x5A=090	Z
0x00, 0x00, 0x7F, 0x41, 0x41, 0x00,				//	060)	0x5B=091	[
0xAA, 0x55, 0xAA, 0x55, 0xAA, 0x55,				//	061)	0x5C=092	 
0x00, 0x00, 0x41, 0x41, 0x7F, 0x00,				//	062)	0x5D=093	]
0x00, 0x04, 0x02, 0x01, 0x02, 0x04,				//	063)	0x5E=094	^
0x00, 0x40, 0x40, 0x40, 0x40, 0x40,				//	064)	0x5F=095	_
												//
0x00, 0x00, 0x03, 0x05, 0x00, 0x00,				//	065)	0x60=096	`
0x00, 0x20, 0x54, 0x54, 0x54, 0x78,				//	066)	0x61=097	a
0x00, 0x7F, 0x28, 0x44, 0x44, 0x38,				//	067)	0x62=098	b
0x00, 0x38, 0x44, 0x44, 0x44, 0x20,				//	068)	0x63=099	c
0x00, 0x38, 0x44, 0x44, 0x48, 0x7F,				//	069)	0x64=100	d
0x00, 0x38, 0x54, 0x54, 0x54, 0x18,				//	070)	0x65=101	e
0x00, 0x08, 0x7E, 0x09, 0x01, 0x02,				//	071)	0x66=102	f
0x00, 0x18, 0xA4, 0xA4, 0xA4, 0x7C,				//	072)	0x67=103	g
0x00, 0x7F, 0x08, 0x04, 0x04, 0x78,				//	073)	0x68=104	h
0x00, 0x00, 0x44, 0x7D, 0x40, 0x00,				//	074)	0x69=105	i
0x00, 0x40, 0x80, 0x84, 0x7D, 0x00,				//	075)	0x6A=106	j
0x00, 0x7F, 0x10, 0x28, 0x44, 0x00,				//	076)	0x6B=107	k
0x00, 0x00, 0x41, 0x7F, 0x40, 0x00,				//	077)	0x6C=108	l
0x00, 0x7C, 0x04, 0x18, 0x04, 0x78,				//	078)	0x6D=109	m
0x00, 0x7C, 0x08, 0x04, 0x04, 0x78,				//	079)	0x6E=110	n
0x00, 0x38, 0x44, 0x44, 0x44, 0x38,				//	080)	0x6F=111	o
												//
0x00, 0xFC, 0x24, 0x24, 0x24, 0x18,				//	081)	0x70=112	p
0x00, 0x18, 0x24, 0x24, 0x18, 0xFC,				//	082)	0x71=113	q
0x00, 0x7C, 0x08, 0x04, 0x04, 0x08,				//	083)	0x72=114	r
0x00, 0x48, 0x54, 0x54, 0x54, 0x20,				//	084)	0x73=115	s
0x00, 0x04, 0x3F, 0x44, 0x40, 0x20,				//	085)	0x74=116	t
0x00, 0x3C, 0x40, 0x40, 0x20, 0x7C,				//	086)	0x75=117	u
0x00, 0x1C, 0x20, 0x40, 0x20, 0x1C,				//	087)	0x76=118	v
0x00, 0x3C, 0x40, 0x30, 0x40, 0x3C,				//	088)	0x77=119	w
0x00, 0x44, 0x28, 0x10, 0x28, 0x44,				//	089)	0x78=120	x
0x00, 0x1C, 0xA0, 0xA0, 0xA0, 0x7C,				//	090)	0x79=121	y
0x00, 0x44, 0x64, 0x54, 0x4C, 0x44,				//	091)	0x7A=122	z
0x00, 0x00, 0x10, 0x7C, 0x82, 0x00,				//	092)	0x7B=123	{
0x00, 0x00, 0x00, 0xFF, 0x00, 0x00,				//	093)	0x7C=124	|
0x00, 0x00, 0x82, 0x7C, 0x10, 0x00,				//	094)	0x7D=125	}
0x00, 0x00, 0x06, 0x09, 0x09, 0x06,				//	095)	0x7E=126	~
												//
0												//	   (0)  . .    .
};//

void display_SmallPrint(uint8_t posx, uint8_t posy, uint8_t *str)
{	uint8_t dt[128];
	uint16_t posfont, posscr;
	uint32_t *adrclear;
	uint32_t timer,timec;
	adrclear=&dt;
	uint8_t code;
	code=*str++;
	for(uint8_t i=0;i<32;i++)
	 { *adrclear++=0; }
	dt[128]=0;
	SSD1306_WRITECOMMAND(0x20);
	SSD1306_WRITECOMMAND(0x00);
	SSD1306_WRITECOMMAND(0x21);
	SSD1306_WRITECOMMAND(0);
	SSD1306_WRITECOMMAND(127);
	SSD1306_WRITECOMMAND(0x22);
	SSD1306_WRITECOMMAND(posy);
	SSD1306_WRITECOMMAND(posy);
	posscr=posx*6;
while (code>31)
{posfont=4+6*(code-32);
 for(uint8_t i = 0; i <6; i++)
  {	dt[i+1+posscr]=SmallFont[i+posfont]; }
	code=*str++;
	posscr+=6;
	if (posscr>127) break;
}
	dt[0] =  0x40;
  	HAL_I2C_Master_Transmit_DMA(&hi2c1, SSD1306_I2C_ADDR, dt, 128+1);
		timec=HAL_GetTick();
		timer=timec+50;
		while ((HAL_I2C_GetState(&hi2c1) != HAL_I2C_STATE_READY)&&(timec<timer))
		{timec=HAL_GetTick();}
}

void display_MediumPrint(uint8_t posx, uint8_t posy, uint8_t *str)
{	uint8_t dt[256+1];
	uint16_t posfont, posscr;
	uint32_t *adrclear;
	uint32_t timer,timec;
	adrclear=&dt;
	uint8_t code;
	code=*str++;
	for(uint8_t i=0;i<64;i++)
	 { *adrclear++=0; }
	dt[256]=0;
	SSD1306_WRITECOMMAND(0x20);
	SSD1306_WRITECOMMAND(0x00);
	SSD1306_WRITECOMMAND(0x21);
	SSD1306_WRITECOMMAND(0);
	SSD1306_WRITECOMMAND(127);
	SSD1306_WRITECOMMAND(0x22);
	SSD1306_WRITECOMMAND(posy);
	SSD1306_WRITECOMMAND(posy+1);
	posscr=posx*12;
while (code>31)
{posfont=4+24*(code-32);
 for(uint8_t i = 0; i <12; i++)
  {	dt[i+1+posscr]=MediumFont[i+posfont];
    dt[i+1+128+posscr]=MediumFont[i+12+posfont]; }
	code=*str++;
	posscr+=12;
	if (posscr>127) break;
}
	dt[0] =  0x40;
  	HAL_I2C_Master_Transmit_DMA(&hi2c1, SSD1306_I2C_ADDR, dt, 256+1);
	timec=HAL_GetTick();
	timer=timec+50;
	while ((HAL_I2C_GetState(&hi2c1) != HAL_I2C_STATE_READY)&&(timec<timer))
	{timec=HAL_GetTick();}

}


